<?php
/**
 * Features Section options
 *
 * @package Theme Palace
 * @subpackage Businesszen
 * @since Businesszen 1.0.0
 */

// Add Features section
$wp_customize->add_section( 'businesszen_our_features_section', array(
	'title'             => esc_html__( 'Features Section','businesszen' ),
	'description'       => esc_html__( 'Features Section options.', 'businesszen' ),
	'panel'             => 'businesszen_front_page_panel',
	'priority'          => 70,
) );

// Features content enable control and setting
$wp_customize->add_setting( 'businesszen_theme_options[features_section_enable]', array(
	'default'			=> 	$options['features_section_enable'],
	'sanitize_callback' => 'businesszen_sanitize_switch_control',
) );

$wp_customize->add_control( new Businesszen_Switch_Control( $wp_customize, 'businesszen_theme_options[features_section_enable]', array(
	'label'             => esc_html__( 'Features Section Enable', 'businesszen' ),
	'section'           => 'businesszen_our_features_section',
	'on_off_label' 		=> businesszen_switch_options(),
) ) );

// Features btn label setting and control
$wp_customize->add_setting( 'businesszen_theme_options[features_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['features_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'businesszen_theme_options[features_subtitle]', array(
	'label'           	=> esc_html__( 'Subtitle', 'businesszen' ),
	'section'        	=> 'businesszen_our_features_section',
	'active_callback' 	=> 'businesszen_is_features_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'businesszen_theme_options[features_subtitle]', array(
		'selector'            => '#businesszen_our_features_section p.section-subtitle',
		'settings'            => 'businesszen_theme_options[features_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'businesszen_features_subtitle_partial',
    ) );
}

// features title setting and control
$wp_customize->add_setting( 'businesszen_theme_options[features_title]',
	array(
		'default'       		=> $options['features_title'],
		'sanitize_callback'		=> 'sanitize_text_field',
		'transport'				=> 'postMessage',
	)
);
$wp_customize->add_control( 'businesszen_theme_options[features_title]',
    array(
		'label'      			=> esc_html__( 'Section Title', 'businesszen' ),
		'section'    			=> 'businesszen_our_features_section',
		'type'		 			=> 'text',
		'active_callback'		=> 'businesszen_is_features_section_enable',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'businesszen_theme_options[features_title]', array(
		'selector'            => '#businesszen_our_features_section h2.section-title',
		'settings'            => 'businesszen_theme_options[features_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'businesszen_features_title_partial',
    ) );
}

// about btn title setting and control
$wp_customize->add_setting( 'businesszen_theme_options[features_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['features_btn_title'],
) );

$wp_customize->add_control( 'businesszen_theme_options[features_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'businesszen' ),
	'section'        	=> 'businesszen_our_features_section',
	'active_callback' 	=> 'businesszen_is_features_section_enable',
	'type'				=> 'text',
) );

for ( $i = 1; $i <= 2; $i++ ) :

	// features posts drop down chooser control and setting
	$wp_customize->add_setting( 'businesszen_theme_options[features_content_post_' . $i . ']', array(
		'sanitize_callback' => 'businesszen_sanitize_page',
	) );

	$wp_customize->add_control( new Businesszen_Dropdown_Chooser( $wp_customize, 'businesszen_theme_options[features_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'businesszen' ), $i ),
		'section'           => 'businesszen_our_features_section',
		'choices'			=> businesszen_post_choices(),
		'active_callback'	=> 'businesszen_is_features_section_enable',
	) ) );

endfor;