<?php
/**
 * Slider Section options
 *
 * @package Theme Palace
 * @subpackage Businesszen
 * @since Businesszen 1.0.0
 */

// Add Slider section
$wp_customize->add_section( 'businesszen_featured_slider_section', array(
	'title'             => esc_html__( 'Main Slider','businesszen' ),
	'description'       => esc_html__( 'Slider Section options.', 'businesszen' ),
	'panel'             => 'businesszen_front_page_panel',
	'priority'          => 20,
	) );

// Slider content enable control and setting
$wp_customize->add_setting( 'businesszen_theme_options[slider_section_enable]', array(
	'default'			=> 	$options['slider_section_enable'],
	'sanitize_callback' => 'businesszen_sanitize_switch_control',
) );

$wp_customize->add_control( new Businesszen_Switch_Control( $wp_customize, 'businesszen_theme_options[slider_section_enable]', array(
	'label'             => esc_html__( 'Slider Section Enable', 'businesszen' ),
	'section'           => 'businesszen_featured_slider_section',
	'on_off_label' 		=> businesszen_switch_options(),
) ) );

// Slider btn label setting and control
$wp_customize->add_setting( 'businesszen_theme_options[slider_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['slider_btn_label'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'businesszen_theme_options[slider_btn_label]', array(
	'label'           	=> esc_html__( 'Slider Button Label', 'businesszen' ),
	'section'        	=> 'businesszen_featured_slider_section',
	'active_callback' 	=> 'businesszen_is_slider_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'businesszen_theme_options[slider_btn_label]', array(
		'selector'            => '#businesszen_featured_slider_section div.read-more a.primary',
		'settings'            => 'businesszen_theme_options[slider_btn_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'businesszen_slider_btn_label_partial',
    ) );
}

for ( $i = 1; $i <= 3; $i++ ) :

	// slider posts drop down chooser control and setting
	$wp_customize->add_setting( 'businesszen_theme_options[slider_content_post_' . $i . ']', array(
		'sanitize_callback' => 'businesszen_sanitize_page',
	) );

	$wp_customize->add_control( new Businesszen_Dropdown_Chooser( $wp_customize, 'businesszen_theme_options[slider_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'businesszen' ), $i ),
		'section'           => 'businesszen_featured_slider_section',
		'choices'			=> businesszen_post_choices(),
		'active_callback'	=> 'businesszen_is_slider_section_enable',
	) ) );

	// Alt btn label setting and control
	$wp_customize->add_setting( 'businesszen_theme_options[slider_alt_btn_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
		) );

	$wp_customize->add_control( 'businesszen_theme_options[slider_alt_btn_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Alternative Button %d', 'businesszen' ), $i ),
		'section'        	=> 'businesszen_featured_slider_section',
		'active_callback' 	=> 'businesszen_is_slider_section_enable',
		'type'				=> 'text',
		) );

	// Alt btn url setting and control
	$wp_customize->add_setting( 'businesszen_theme_options[slider_alt_btn_url_' . $i . ']', array(
		'sanitize_callback' => 'esc_url_raw',
		) );

	$wp_customize->add_control( 'businesszen_theme_options[slider_alt_btn_url_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Alternative Button Link %d', 'businesszen' ), $i ),
		'section'        	=> 'businesszen_featured_slider_section',
		'active_callback' 	=> 'businesszen_is_slider_section_enable',
		'type'				=> 'url',
		) );

endfor;