<?php
/**
 * About section
 *
 * This is the template for the content of about section
 *
 * @package Theme Palace
 * @subpackage Businesszen
 * @since Businesszen 1.0.0
 */
if ( ! function_exists( 'businesszen_add_about_section' ) ) :
    /**
    * Add about section
    *
    *@since Businesszen 1.0.0
    */
    function businesszen_add_about_section() {
    	$options = businesszen_get_theme_options();
        // Check if about is enabled on frontpage
        $about_enable = apply_filters( 'businesszen_section_status', true, 'about_section_enable' );

        if ( true !== $about_enable ) {
            return false;
        }
        // Get about section details
        $section_details = array();
        $section_details = apply_filters( 'businesszen_filter_about_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render about section now.
        businesszen_render_about_section( $section_details );
    }
endif;

if ( ! function_exists( 'businesszen_get_about_section_details' ) ) :
    /**
    * about section details.
    *
    * @since Businesszen 1.0.0
    * @param array $input about section details.
    */
    function businesszen_get_about_section_details( $input ) {
        $options = businesszen_get_theme_options();
        
        $content = array();
        $post_id = ! empty( $options['about_content_post'] ) ? $options['about_content_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    );

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['excerpt']   = businesszen_trim_content( 60 );
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// about section content details.
add_filter( 'businesszen_filter_about_section_details', 'businesszen_get_about_section_details' );


if ( ! function_exists( 'businesszen_render_about_section' ) ) :
  /**
   * Start about section
   *
   * @return string about content
   * @since Businesszen 1.0.0
   *
   */
   function businesszen_render_about_section( $content_details = array() ) {
        $options = businesszen_get_theme_options();
        $about_btn_title = ! empty( $options['about_btn_title'] ) ? $options['about_btn_title'] : '';

        if ( empty( $content_details ) ) {
            return;
        } 
        ?>
        <?php foreach ( $content_details as $content ): ?>

        <div id="businesszen_about_us_section" class="relative page-section same-background">
            <div class="wrapper">
                <article class="has-post-thumbnail">
                    <?php if( !empty( $content['url'] ) && !empty( $content['image'] ) ): ?>
                        <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                            <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                        </div><!-- .featured-image -->
                    <?php endif; ?>

                    <div class="entry-container">
                        <div class="section-header">
                            <?php if( !empty( $options['about_subtitle'] ) ): ?>
                                <p class="section-subtitle"><?php echo esc_html( $options['about_subtitle'] ); ?></p>
                            <?php endif; ?>

                            <?php if( !empty( $content['title'] ) ): ?>
                                <h2 class="section-title"><?php echo esc_html( $content['title'] ) ; ?></h2>
                            <?php endif; ?>
                        </div><!-- .section-header -->

                        <?php if( !empty( $content['excerpt'] ) ): ?>
                            <div class="entry-content">
                                <p><?php echo wp_kses_post( $content['excerpt'] ) ; ?></p>
                            </div><!-- .entry-content -->
                        <?php endif; ?>

                        <?php if( !empty( $content['url'] ) && !empty( $options['about_btn_title'] ) ): ?>
                            <div class="read-more">
                                <a href="<?php echo esc_url( $content['url'] ) ; ?>" class="btn"><?php echo esc_html( $options['about_btn_title'] ) ; ?></a>
                            </div><!-- .read-more -->
                        <?php endif; ?>
                    </div><!-- .entry-container -->
                </article>
            </div><!-- .wrapper -->
        </div><!-- #businesszen_about_us_section -->

    <?php 
    endforeach;
}
endif;