<?php
/**
 * Service section
 *
 * This is the template for the content of service section
 *
 * @package Theme Palace
 * @subpackage Businesszen
 * @since Businesszen 1.0.0
 */
if ( ! function_exists( 'businesszen_add_service_section' ) ) :
    /**
    * Add service section
    *
    *@since Businesszen 1.0.0
    */
    function businesszen_add_service_section() {
        $options = businesszen_get_theme_options();
        // Check if service is enabled on frontpage
        $service_enable = apply_filters( 'businesszen_section_status', true, 'service_section_enable' );

        if ( true !== $service_enable ) {
            return false;
        }
        // Get service section details
        $section_details = array();
        $section_details = apply_filters( 'businesszen_filter_service_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render service section now.
        businesszen_render_service_section( $section_details );
    }
endif;

if ( ! function_exists( 'businesszen_get_service_section_details' ) ) :
    /**
    * service section details.
    *
    * @since Businesszen 1.0.0
    * @param array $input service section details.
    */
    function businesszen_get_service_section_details( $input ) {
        $options = businesszen_get_theme_options();
        
        $content = array();
       $post_ids = array();

                for ( $i = 1; $i <= 6; $i++ ) {
                    if ( ! empty( $options['service_content_post_' . $i] ) )
                        $post_ids[] = $options['service_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => 6,
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );

        // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = businesszen_trim_content( 15 );
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// service section content details.
add_filter( 'businesszen_filter_service_section_details', 'businesszen_get_service_section_details' );


if ( ! function_exists( 'businesszen_render_service_section' ) ) :
  /**
   * Start service section
   *
   * @return string service content
   * @since Businesszen 1.0.0
   *
   */
   function businesszen_render_service_section( $content_details = array() ) {
        $options = businesszen_get_theme_options();
        $service_title = ! empty( $options['service_title'] ) ? $options['service_title'] : '';
        $service_sub_title = ! empty( $options['service_sub_title'] ) ? $options['service_sub_title'] : '';

        if ( empty( $content_details ) ) {
            return;
        } 
        ?> 

        <div id="businesszen_our_services_section" class="relative page-section same-background">
            <div class="wrapper">

                <div class="section-header">
                    <?php if( !empty( $service_sub_title ) ): ?>
                        <p class="section-subtitle"><?php echo esc_html( $service_sub_title ); ?></p>
                    <?php endif;

                    if( !empty( $service_title ) ):
                        ?>
                    <h2 class="section-title"><?php echo esc_html( $service_title ); ?></h2>

                <?php endif; ?>

            </div><!-- .section-header -->

            <div class="section-content col-3 clear">

                <?php $i = 1; foreach ( $content_details as $content ) : ?>

                <article>
                    <div class="service-item-wrapper">
                        <div class="entry-container">
                            <div class="icon-container">
                                <a href="<?php echo esc_url( $content['url'] ); ?>"><i class="fa <?php echo ! empty( $options['service_content_icon_' . $i] ) ? esc_attr( $options['service_content_icon_' . $i] ) : 'fa-desktop'; ?>"></i></a>
                            </div><!-- .icon-container -->

                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                            </header>

                            <div class="entry-content">
                                <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                            </div><!-- .entry-content -->

                            <?php
                            if( !empty( $options['service_btn'] ) ): ?>
                            <div class="read-more">
                                <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn"><?php echo esc_html( $options['service_btn'] ); ?></a>
                            </div><!-- .read-more -->

                        <?php endif; ?>

                    </div><!-- .entry-container -->
                </div><!-- .service-item-wrapper -->
            </article>

            <?php $i++; endforeach; ?>

        </div><!-- .col-3 -->

</div><!-- .wrapper -->
</div>

    <?php }
endif;